/*--- (c) 2002 iWombat.com All rights reserved ---*/

package com.iwombat.foundation.environment;



import java.util.*;
import java.net.*;
import java.io.IOException;


/**
 *
 * This singleton class locates configurations and configuration maps and caches them 
 * for later use
 *
 * @author  $Author: brentp $
 * @version $Revision: 1.4 $
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2002/11/04 01:20:10 $</dd></dl>
 * 
 */
public class ConfigurationLocator{
    /**
     * Synchronized for your protection
     */
    private static Map configMaps = Collections.synchronizedMap(new HashMap());
    private static Map configProps= Collections.synchronizedMap(new HashMap());    
    
    /**
     * Locate or create a ConfigurationMap for the specified key
     *
     * @param configListKey
     * @return the config map
     */
    public static ConfigurationMap getConfigurationMap(String configMapName){
        ConfigurationMap map = (ConfigurationMap)configMaps.get(configMapName);
        if (null == map) {
            URL configMapURL = ConfigurationURLUtil.getConfigurationMapURLForKey(configMapName);
            map = new ConfigurationMap(configMapName, configMapURL);
            configMaps.put(map.getName(), map);
        }
        return map;
    }

   /**
    * Shortcut method to return a specified configuration from a config map
    *
    * @param map name - the name of the config map
    * @param config name - the name of the specific config
    */
   public static Configuration getConfiguration(String mapName, String configName) {
       return getConfigurationMap(mapName).getConfiguration(configName);     
   }

   /**
    * Shortcut method to return a specified property value for a given property config key
    *
    * @param propertyKey the key for the specific property set
    * @param key the property key for the specified property set 
    * @return the value for the specified keys
    */
   public static String getPropertyValue(String propertyKey, String key){
       return getProperties(propertyKey).getProperty(key);
   }
   
   /**
    * Shortcut method to return the Properties for the specified key
    *
    * @param propertyKey the key for the specific property set
    * @return the properties for the specified key
    *
    */
	
   public static Properties getProperties(String propertyKey){

       Properties props = (Properties)configProps.get(propertyKey);
       
       if (null == props){
        
           URL configPropsURL = ConfigurationURLUtil.getConfigurationMapURLForKey(propertyKey);
           
           props = new Properties();
           
           try{
               URLConnection conn= configPropsURL.openConnection();
               props.load(conn.getInputStream());
               configProps.put(propertyKey, props);
           }
           catch (IOException e){

               throw new ConfigurationException("Unable to read config URL : " + e.getMessage());
               }
               
        }
       
       return props;
   }
	
}
