// Copyright (c) 2002 Capitalstream Inc. All rights reserved
package com.iwombat.foundation.log;

import org.apache.log4j.*;

import java.util.*;
import com.iwombat.foundation.environment.*;
import com.iwombat.util.URLUtil;


/**
 * Facade for logging into log4j framework. Includes convienience methods for the various log levels.
 *
 * @author $Author: bob $
 * @version $Revision: 1.1 $
 * @date $Date: 2002/11/29 21:01:36 $
 */
public class Log {

    private static final String configKey = "log4jConfig";

    static {
        try {
            Properties logProps = ConfigurationLocator.getProperties(configKey); 
            PropertyConfigurator.configure(logProps);
        } catch (Throwable throwable) {
            System.err.print(
                "Fatal error in creating logger - can not find config file for key"
                + configKey);
        }
    }

    /**
     * Logs a message to the specified log level. Accepts a throwable for additional context information.
     *
     *
     * @param callingObjectRef the originating object
     * @param level the log level of the message
     * @param message the text of the message
     * @param throwable the throwable we caught to inspire this message
     *
     */
    protected static void log(Object callingObjectRef, Level level, String message, Throwable throwable) {
        log(callingObjectRef.getClass().getName(), level, message, throwable);
    }

    /**
     * Log a message and include a throwable
     *
     *
     * @param categoryName
     * @param level
     * @param message
     * @param throwable
     *
     */
    protected static void log(String categoryName,
                              Level level, String message, Throwable throwable) {
        Logger.getLogger(categoryName).log(level, message, throwable);
    }

    /**
     * Logs a message at debug level.
     *
     *
     * @param callingObjectRef the originating object
     * @param message the log message
     *
     */
    public static void debug(Object callingObjectRef, String message) {
        debug(callingObjectRef.getClass().getName(), message, (Throwable) null);
    }

    /**
     * Logs a message at debug level triggered by catching a throwable.
     *
     *
     * @param callingObjectRef the originating object
     * @param message the message to log
     * @param throwable the throwable triggering this log event
     *
     */
    public static void debug(Object callingObjectRef, String message, Throwable throwable) {
        debug(callingObjectRef.getClass().getName(), message, throwable);
    }

    /**
     * Logs a message at debug level
     *
     *
     * @param category the category of the log message
     * @param message the message to log
     *
     */
    public static void debug(String category, String message) {
        debug(category, message, (Throwable) null);
    }

    /**
     * Logs a message at debug level
     *
     *
     * @param category the category of the log message
     * @param message the message to log
     * @param throwable the throwable triggering this log event
     *
     */
    public static void debug(String category, String message, Throwable throwable) {
        log(category, Level.DEBUG, message, throwable);
    }

    // The INFO level sigs

    /**
     * Logs a message at info level
     *
     *
     * @param callingObjectRef the originating object
     * @param message the message to log
     *
     */
    public static void info(Object callingObjectRef, String message) {
        info(callingObjectRef.getClass().getName(), message, (Throwable) null);
    }

    /**
     * Logs a message at info level triggered by catching a throwable.
     *
     *
     * @param callingObjectRef the originating object
     * @param message the message to log
     * @param throwable the throwable triggering this log event
     *
     */
    public static void info(Object callingObjectRef, String message, Throwable throwable) {
        info(callingObjectRef.getClass().getName(), message, throwable);
    }

    /**
     * Logs a message at info level
     *
     *
     * @param category the category of the log message
     * @param message the message to log
     *
     */
    public static void info(String category, String message) {
        info(category, message, (Throwable) null);
    }

    /**
     * Logs a message at info level
     *
     *
     * @param category the category of the log message
     * @param message the message to log
     * @param throwable the throwable triggering this log event
     *
     */
    public static void info(String category, String message, Throwable throwable) {
        log(category, Level.INFO, message, throwable);
    }

    // The WARN level sigs   

    /**
     * Logs a message at warn level
     *
     *
     * @param callingObjectRef the originating object
     * @param message the message to log
     *
     */
    public static void warn(Object callingObjectRef, String message) {
        warn(callingObjectRef.getClass().getName(), message, (Throwable) null);
    }

    /**
     * Logs a message at warn level
     *
     *
     * @param callingObjectRef
     * @param message the message to log
     * @param throwable the throwable triggering this log event
     *
     */
    public static void warn(Object callingObjectRef, String message, Throwable throwable) {
        warn(callingObjectRef.getClass().getName(), message, throwable);
    }

    /**
     * Logs a message at warn level
     *
     *
     * @param category the category of the log message
     * @param message the message to log
     *
     */
    public static void warn(String category, String message) {
        warn(category, message, (Throwable) null);
    }

    /**
     * Logs a message at warn level
     *
     *
     * @param category the category of the log message
     * @param message the message to log
     * @param throwable the throwable triggering this log event
     *
     */
    public static void warn(String category, String message, Throwable throwable) {
        log(category, Level.WARN, message, throwable);
    }

    // The ERROR level sigs  

    /**
     * Logs a message at error level
     *
     *
     * @param callingObjectRef the originating object
     * @param message the message to log
     *
     */
    public static void error(Object callingObjectRef, String message) {
        error(callingObjectRef.getClass().getName(), message, (Throwable) null);
    }

    /**
     * Logs a message at error level
     *
     *
     * @param callingObjectRef the originating object
     * @param message the message to log
     * @param throwable the throwable triggering this log event
     *
     */
    public static void error(Object callingObjectRef, String message, Throwable throwable) {
        error(callingObjectRef.getClass().getName(), message, throwable);
    }

    /**
     * Logs a message at error level
     *
     *
     * @param category the category of the log message
     * @param message the message to log
     *
     */
    public static void error(String category, String message) {
        error(category, message, (Throwable) null);
    }

    /**
     * Logs a message at error level
     *
     *
     * @param category the category of the log message
     * @param message the message to log
     * @param throwable the throwable triggering this log event
     *
     */
    public static void error(String category, String message, Throwable throwable) {
        log(category, Level.ERROR, message, throwable);
    }

    // The FATAL level sigs  

    /**
     * Logs a message at fatal level
     *
     *
     * @param callingObjectRef the originating object
     * @param message the message to log
     *
     */
    public static void fatal(Object callingObjectRef, String message) {
        fatal(callingObjectRef.getClass().getName(), message,  (Throwable) null);
    }

    /**
     * Logs a message at fatal level
     *
     *
     * @param callingObjectRef the originating object
     * @param message the message to log
     * @param throwable the throwable triggering this log event
     *
     */
    public static void fatal(Object callingObjectRef, String message, Throwable throwable) {
        fatal(callingObjectRef.getClass().getName(), message, throwable);
    }

    /**
     * Logs a message at fatal level
     *
     *
     * @param category the category of the log message
     * @param message the message to log
     *
     */
    public static void fatal(String category, String message) {
        fatal(category, message, (Throwable) null);
    }

    /**
     * Logs a message at fatal level
     *
     *
     * @param category the category of the log message
     * @param message the message to log
     * @param throwable the throwable triggering this log event
     *
     */
    public static void fatal(String category, String message, Throwable throwable) {
        log(category, Level.FATAL, message, throwable);
    }

    /**
     * Check if debug level is enabled
     *
     *
     * @param category the category of the log message
     *
     * @return true if debug is enabled for the specified category
     *
     */
    public static boolean isDebugEnabled(String category) {
        return Logger.getLogger(category).isDebugEnabled();
    }

    /**
     * Check if debug level is enabled
     *
     *
     * @param callingObjectRef the originating object
     *
     * @return true if debug is enabled for the category of the specified object
     *
     */
    public static boolean isDebugEnabled(Object callingObjectRef) {

        return Logger.getLogger(callingObjectRef.getClass().getName()).isDebugEnabled();
    }

    /**
     * Check if info level is enabled
     *
     *
     * @param category the category of the log message
     *
     * @return true if info is enabled for the specified category
     *
     */
    public static boolean isInfoEnabled(String category) {
        return Logger.getLogger(category).isInfoEnabled();
    }

    /**
     * Check if info level is enabled
     *
     *
     * @param callingObjectRef
     *
     * @return true if info is enabled for the category of the object reference
     *
     */
    public static boolean isInfoEnabled(Object callingObjectRef) {
        return Logger.getLogger(callingObjectRef.getClass().getName()).isInfoEnabled();
    }
}

