// (c) Copyright 2001-2002 iwombat.com all rights reserved
package com.iwombat.foundation.persist;

import java.util.ArrayList;
import com.iwombat.foundation.environment.Configuration;

/**
 * Represents a persistable operation configuration
 * <br><br>
 * A JDBC prepared statement is associated with bean-to-parameter mappings (beanParameterMappings) and query result-to-bean mappings (beanQueryResultMappings)
 * <br><br>
 * This way, it is possible to specify bean parameters to load data into a prepared statement, as well as specifying bean parameters to load query results into, or a combination of both, if
 * appropriate.
 * <br><br>
 * This class makes no attempt to verify that the text of the prepared statement parameters and/or column names map correctly to the configured mappings.
 *
 * @author  $Author: brentp $
 * @version $Revision: 1.3 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2002/11/18 16:04:40 $</dd></dl>
 */

public class RdbmsDAOOperationConfig implements Configuration{
    
    private String key=null;
    private String preparedStatement=null;
    private ArrayList beanParameterMappings=null;
    private ArrayList beanQueryResultMappings=null;
    
    /** Creates a new instance of RdbmsPersistableOperationConfig */
    public RdbmsDAOOperationConfig() {
    }
    
    /**
     * retrieves the key representing this persistable operation
     * 
     * @return the key for this operation
     */
    public String getKey(){
        return this.key;
    }
    
    /**
     * sets the key representing this persistable operation
     *
     * @param the key for this operation
     */
    public void setKey(String key){
        this.key=key;
    }

    /**
     * retrieves the prepared statement string
     *
     * @return the prepared statement string
     */
    public String getPreparedStatement(){
        return this.preparedStatement;
    }
    
    /**
     * sets the prepared statement string
     *
     * @param the prepared statement string
     *
     */
    public void setPreparedStatement(String preparedStatement){
        this.preparedStatement=preparedStatement;
    }

    /**
     * returns the bean parameter mapping list for this operation
     *
     * @return the list of bean parameter mappings
     * @see com.iwombat.foundation.OrdinalParameterToBeanMapItem
     */
    public ArrayList getBeanParameterMappings(){
        return this.beanParameterMappings;
    }

    /**
     * sets the bean parameter mapping list for this operation
     * 
     * @param the list of bean parameter mappings
     * @see com.iwombat.foundation.OrdinalParameterToBeanMapItem
     */
    public void setBeanParameterMappings(ArrayList beanParameterMappings){
        this.beanParameterMappings=beanParameterMappings;
    }
    
    /**
     * sets the bean query result mapping list for this operation
     *
     * @param the list of bean query result mappings
     * @see com.iwombat.foundation.QueryResultToBeanMapItem
     */
    public void setBeanQueryResultMappings(ArrayList beanQueryResultMappings){
        this.beanQueryResultMappings=beanQueryResultMappings;
    }
     
    /**
     * retrieves the bean query result mapping list for this operation
     *
     * @return the list of bean query result mappings
     * @see com.iwombat.foundation.QueryResultToBeanMapItem
     */  
    public ArrayList getBeanQueryResultMappings(){
        return this.beanQueryResultMappings;
    }
    
    
    
    
}
