// (c) Copyright 2001-2002 iwombat.com all rights reserved
package com.iwombat.foundation.persist;

import java.sql.*;

import java.lang.reflect.*;

import com.iwombat.util.*;

import com.iwombat.foundation.Identifier;

/**
 * Standard Bean to Sql Parameter mapper
 * maps the following obect to sql data types:
 * <br><br>
 * java.lang.String = java.sql.Types.VARCHAR
 * <br>
 * com.iwombat.Identifier = java.sql.Types.BINARY
 * <br>
 * java.lang.Long = java.sql.Types.INTEGER
 * <br>
 * java.lang.Float = java.sql.Types.NUMERIC
 * <br>
 * java.lang.Boolean = java.sql.Types.TINYINT
 * <br>
 * com.iwombat.ByteArray = java.sql.Types.BINARY
 * <br>
 * java.util.Date = java.sql.Types.TIMESTAMP
 * <br>
 *
 * @author  $Author: brentp $
 * @version $Revision: 1.1 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2002/11/18 16:04:40 $</dd></dl>
 */

public class StandardBeanToSqlParameterMapper extends AbstractBeanToSqlParameterMapper{

 
    /**
     * writes a Boolean value from the currently set source Bean into the currently set Prepared Statement for the
     * specified parameter index
     *
     * @param the Boolean value to set
     * @param the parameter index to write into
     */
    public void writeBooleanParameter(Boolean booleanValue,  int parameterIndex) throws SQLException {
    
        PreparedStatement p = this.getTargetPreparedStatement();
        if (null==p) throw new IllegalStateException("target prepared statement is not defined");
        
        if (null==booleanValue){
            p.setNull(parameterIndex,java.sql.Types.TINYINT);
        }
        else{
            p.setInt(parameterIndex,(booleanValue.booleanValue()==true?1:0));
        }
    }
    
    /**
     * writes a ByteArray value from the currently set source Bean into the currently set Prepared Statement for the
     * specified parameter index
     *
     * @param the ByteArray value to set
     * @param the parameter index to write into
     */
    public void writeByteArrayParameter(ByteArray byteArrayValue,  int parameterIndex)  throws SQLException{
        
        PreparedStatement p = this.getTargetPreparedStatement();
        if (null==p) throw new IllegalStateException("target prepared statement is not defined");
        
        if (null==byteArrayValue){
            p.setNull(parameterIndex,java.sql.Types.BINARY);
        }
        else{
            p.setBytes(parameterIndex,byteArrayValue.byteArrayValue());
        }
    }
    
    /**
     * writes a Date value from the currently set source Bean into the currently set Prepared Statement for the
     * specified parameter index
     *
     * @param the Date value to set
     * @param the parameter index to write into
     */
    public void writeDateParameter(java.util.Date dateValue,  int parameterIndex) throws SQLException {
        
        PreparedStatement p = this.getTargetPreparedStatement();
        if (null==p) throw new IllegalStateException("target prepared statement is not defined");
        
        if (null==dateValue){
            p.setNull(parameterIndex,java.sql.Types.TIMESTAMP);
        }
        else{
            p.setTimestamp(parameterIndex,new Timestamp(dateValue.getTime()));
        }
        
    }
    
    /**
     * writes a Float value from the currently set source Bean into the currently set Prepared Statement for the
     * specified parameter index
     *
     * @param the Float value to set
     * @param the parameter index to write into
     */
    public void writeFloatParameter(Float floatValue,  int parameterIndex) throws SQLException {
        
        PreparedStatement p = this.getTargetPreparedStatement();
        if (null==p) throw new IllegalStateException("target prepared statement is not defined");
        
        if (null==floatValue){
            p.setNull(parameterIndex,java.sql.Types.NUMERIC);
            }
        else{
            p.setFloat(parameterIndex,floatValue.floatValue());
        }
        
    }
    
    /**
     * writes an Identifier value from the currently set source Bean into the currently set Prepared Statement for the
     * specified parameter index
     *
     * @param the Identifier value to set
     * @param the parameter index to write into
     */
    public void writeIdentifierParameter(Identifier identifierValue,  int parameterIndex) throws SQLException{
        
        PreparedStatement p = this.getTargetPreparedStatement();
        if (null==p) throw new IllegalStateException("target prepared statement is not defined");
        
        if (null==identifierValue){
            p.setNull(parameterIndex,java.sql.Types.BINARY);
        }
        else{
            p.setBytes(parameterIndex, identifierValue.getValue());
        }
    }
    
    /**
     * writes a Long value from the currently set source Bean into the currently set Prepared Statement for the
     * specified parameter index
     *
     * @param the Long value to set
     * @param the parameter index to write into
     */
    public void writeLongParameter(Long longValue,  int parameterIndex) throws SQLException {
        
        PreparedStatement p = this.getTargetPreparedStatement();
        if (null==p) throw new IllegalStateException("target prepared statement is not defined");
        
        if (null==longValue){
            p.setNull(parameterIndex,java.sql.Types.INTEGER);
        }
        else{
            p.setLong(parameterIndex, longValue.longValue());
        }
    }
    
    /**
     * writes a String value from the currently set source Bean into the currently set Prepared Statement for the
     * specified parameter index
     *
     * @param the String value to set
     * @param the parameter index to write into
     */
    public void writeStringParameter(String stringValue,  int parameterIndex) throws SQLException {
        
        PreparedStatement p = this.getTargetPreparedStatement();
        if (null==p) throw new IllegalStateException("target prepared statement is not defined");
        
        if (null==stringValue){
            p.setNull(parameterIndex,java.sql.Types.VARCHAR);
        }
        else{
            p.setString(parameterIndex, stringValue);
        }
    }
    
    
}
