// (c) Copyright 2001-2002 iwombat.com all rights reserved
package com.iwombat.foundation.persist;

/**
 * Standard result set to Bean mapper
 * maps the following sql data types to object types:
 * <br><br>
 * java.sql.Types.VARCHAR = java.lang.String
 * <br>
 * java.sql.Types.BINARY = com.iwombat.Identifier
 * <br>
 * java.sql.Types.INTEGER = java.lang.Long
 * <br>
 * java.sql.Types.NUMERIC = java.lang.Float
 * <br>
 * java.sql.Types.TINYINT = java.lang.Boolean
 * <br>
 * java.sql.Types.BINARY = com.iwombat.ByteArray
 * <br>
 * java.sql.Types.TIMESTAMP = java.util.Date
 * <br>
 *
 * @author  $Author: brentp $
 * @version $Revision: 1.1 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2002/11/18 16:04:40 $</dd></dl>
 */
import java.lang.reflect.Method;

import java.sql.*;

import java.util.*;

import com.iwombat.util.*;

import com.iwombat.foundation.*;


public class StandardResultSetToBeanMapper extends AbstractResultSetToBeanMapper {


    /**
     * writes an Identifier value into the currently set target Bean from the currently set source result set
     *
     * @param the mutator method from the target Bean
     * @param the column name to use from the source result set
     */
    public void setIdentifierBeanProperty(Method mutatorMethod, String columnName) throws java.sql.SQLException  {
        
        ResultSet resultSet=this.getSourceResultSet();
        byte[] idBytes=resultSet.getBytes(columnName);
        invokeBeanPropertySetter(mutatorMethod, resultSet.wasNull()?null:IdentifierFactory.createUniqueIdentifier(idBytes));
    }
    
    /**
     * writes a String value into the currently set target Bean from the currently set source result set
     *
     * @param the mutator method from the target Bean
     * @param the column name to use from the source result set
     */
    public void setStringBeanProperty(Method mutatorMethod, String columnName) throws java.sql.SQLException{
        
        ResultSet resultSet=this.getSourceResultSet();        
        String stringValue=resultSet.getString(columnName);
        invokeBeanPropertySetter(mutatorMethod,resultSet.wasNull()?null:new String(stringValue));
    }

    /**
     * writes a Boolean value into the currently set target Bean from the currently set source result set
     *
     * @param the mutator method from the target Bean
     * @param the column name to use from the source result set
     */
    public void setBooleanBeanProperty(Method mutatorMethod, String columnName) throws java.sql.SQLException{
        
        ResultSet resultSet=this.getSourceResultSet();
        boolean boolValue=resultSet.getBoolean(columnName);
        invokeBeanPropertySetter(mutatorMethod,resultSet.wasNull()?null:new Boolean(boolValue));
    }
    
    /**
     * writes a ByteArray value into the currently set target Bean from the currently set source result set
     *
     * @param the mutator method from the target Bean
     * @param the column name to use from the source result set
     */
    public void setByteArrayBeanProperty(Method mutatorMethod, String columnName) throws java.sql.SQLException{
        
        ResultSet resultSet=this.getSourceResultSet();
        byte[] bytesValue=resultSet.getBytes(columnName);
        invokeBeanPropertySetter(mutatorMethod,resultSet.wasNull()?null:new ByteArray(bytesValue));
    }
    
    /**
     * writes a java.util.Date value into the currently set target Bean from the currently set source result set
     *
     * @param the mutator method from the target Bean
     * @param the column name to use from the source result set
     */
    public void setDateBeanProperty(Method mutatorMethod, String columnName) throws java.sql.SQLException{
        
        ResultSet resultSet=this.getSourceResultSet();
        Timestamp timestampValue=resultSet.getTimestamp(columnName);
        invokeBeanPropertySetter(mutatorMethod,resultSet.wasNull()?null:new java.util.Date(timestampValue.getTime()));
    }
    
    /**
     * writes a Float value into the currently set target Bean from the currently set source result set
     *
     * @param the mutator method from the target Bean
     * @param the column name to use from the source result set
     */
    public void setFloatBeanProperty(Method mutatorMethod, String columnName) throws java.sql.SQLException{
        
        ResultSet resultSet=this.getSourceResultSet();
        float floatValue=resultSet.getFloat(columnName);
        invokeBeanPropertySetter(mutatorMethod,resultSet.wasNull()?null:new Float(floatValue));
    }
    
    /**
     * writes a Long value into the currently set target Bean from the currently set source result set
     *
     * @param the mutator method from the target Bean
     * @param the column name to use from the source result set
     */
    public void setLongBeanProperty(Method mutatorMethod, String columnName) throws java.sql.SQLException{
        
        ResultSet resultSet=this.getSourceResultSet();
        long longValue=resultSet.getLong(columnName);
        invokeBeanPropertySetter(mutatorMethod,resultSet.wasNull()?null:new Long(longValue));
    }
    
    
}
