/*--- (c) 2003 iWombat.com All rights reserved ---*/

package com.iwombat.swing;

import javax.swing.*;
import javax.swing.event.*;
import java.awt.event.*;
import java.beans.*;

/**
 * A window menu component for handling window flipping behavior in a 
 * JDesktopPane from a menu.
 * 
 * @author  $Author: bob $
 * @version $Revision: 1.2 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2003/06/12 23:52:48 $</dd></dl>
*/

public class MultiDocumentWindowMenu extends JMenu {
    private MultiDocumentDesktopPane desktop;
    public void setDesktop(MultiDocumentDesktopPane pane) { 
        desktop = pane; 
        this.initDesktopListeners();
    }
    public MultiDocumentDesktopPane getDesktop() { return desktop; }

    private JMenuItem cascade=new JMenuItem("Cascade");
    public void setCascade(JMenuItem menuItem) { cascade = menuItem; }
    public JMenuItem getCascade() { return cascade; }

    private JMenuItem tile=new JMenuItem("Tile");
    public void setTile(JMenuItem menuItem) { tile = menuItem; }
    public JMenuItem getTile() { return tile; }

    public MultiDocumentWindowMenu() {
	super();
        this.setText("Window");
    }

    public MultiDocumentWindowMenu(MultiDocumentDesktopPane newDesktop) {
       
        super(); 
        this.setText("Window");
        this.setDesktop(newDesktop);
    }

    private void initDesktopListeners() {
        cascade.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent ae) {
                MultiDocumentWindowMenu.this.desktop.cascadeFrames();
            }
        });
        tile.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent ae) {
                MultiDocumentWindowMenu.this.desktop.tileFrames();
            }
        });
        addMenuListener(new MenuListener() {
            public void menuCanceled (MenuEvent e) {}

            public void menuDeselected (MenuEvent e) {
                removeAll();
            }

            public void menuSelected (MenuEvent e) {
                buildWindowMenu();
            }
        });
    }

    // convienience method for constructing the window menu and its items
    private void buildWindowMenu() {
        int i;
        WindowMenuItem menu;
        JInternalFrame[] frames = desktop.getAllFrames();

        this.add(cascade);
        this.add(tile);
        
        
        boolean haveFrames = (frames.length > 1);
        
        if (frames.length > 0) {
            addSeparator();
        }
        
        cascade.setEnabled(haveFrames);
        tile.setEnabled(haveFrames);

        for (i = 0; i < frames.length; i++) {
            menu = new WindowMenuItem(frames[i]);
            menu.setState(i == 0);
            menu.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent ae) {
                    JInternalFrame aFrame = ((WindowMenuItem)ae.getSource()).getFrame();
                    aFrame.moveToFront();
                    try {
                        aFrame.setSelected(true);
                    } catch (PropertyVetoException e) {
                        // gobble up the exception
                    }
                }
            });
            menu.setIcon(frames[i].getFrameIcon());
            this.add(menu);
        }
    }

    /* This JCheckBoxMenuItem descendant is used to track the child frame that corresponds
       to a give menu. */
    class WindowMenuItem extends JCheckBoxMenuItem {
        private JInternalFrame frame;

        public WindowMenuItem(JInternalFrame frame) {
            super(frame.getTitle());
            this.frame = frame;
        }

        public JInternalFrame getFrame() {
            return frame;
        }
    }
}
