/*--- (c) 2002 iWombat.com All rights reserved ---*/


package com.iwombat.util;


import java.net.URL;
import java.net.MalformedURLException;

/**
 * A utility class for creating well-formed URLs
 *
 * @author  $Author: bob $
 * @version $Revision: 1.3 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2002/10/14 05:06:07 $</dd></dl>
 */

public class URLUtil {
    /*
     * This utility method attempts to create a URL from the specified target
     * if this fails it attempts again by prepending the base to the target
     *
     * @param base - a base url ex. http://myserver.com/mypath/
     * @param target - a target, may be a fully qualified URL or a simple filename
     *
     * @throws MalformedURLException if a valid URL cannot be constructed
     */
    public static URL createURL(String base, String target)
    throws MalformedURLException {
        URL newURL = null;
        try {
            newURL = new URL(target);
            return newURL;
        } catch (MalformedURLException e) {
            String fullPath = new String(base + target);
            newURL = new URL(fullPath);
            return newURL;
        }
    }
    
    /*
     * This utility method strips a filename off the end of a URL and returns
     * a URL comprised of just the directory.
     *
     * @param base - a fully qualified URL with a filename
     * @return strippedURL - a url with just the directory
     * @throws MalformedURLException if a valid URL cannot be constructed
     */
    public static URL stripURLFile(URL fullURL)
    throws MalformedURLException {
        String urlPath = fullURL.toString();
        int index = urlPath.lastIndexOf("/");
        String urlBase = urlPath.substring(0, index + 1);
        URL strippedURL = new URL(urlBase);
        return strippedURL;
    }
}
