/*--- (c) 2002 iWombat.com All rights reserved ---*/
package com.iwombat.foundation.environment;

import junit.framework.*;
import java.net.*;

import com.iwombat.foundation.TstTimeResourceLocator;
import com.iwombat.util.URLUtil;

/**
 * Description
 *
 * @author  $Author: bob $
 * @version $Revision: 1.5 $
 *              $Date: 2003/10/08 05:04:55 $
 *
 */

public class ConfigurationMapTest extends TestCase {
    private static final String CONFIG1 = "config1";
    private static final String CONFIG2 = "config2";
    
    public ConfigurationMapTest(java.lang.String testName) {
        super(testName);
    }
    
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(ConfigurationMapTest.class);
        return suite;
    }
    
    // Add test methods here, they have to start with 'test' name.
    // for example:
    // public void testHello() {}
    
    public void testConfigReadWrite() {
        String userHome = System.getProperty("user.home");
        String outFile = userHome + "/.configMapTest.xml";
        
        URL outURL = null;
        try {
            outURL = new URL("file:////" + outFile);
        } catch (MalformedURLException e) {
            fail("Can not create url for file" + outFile);
        }
        
        
        String configMapName = "configMapTest";
        
        
        FooConfig conf1 = new FooConfig();
        FooConfig conf2 = new FooConfig();
        
        conf1.setKey(CONFIG1);
        conf2.setKey(CONFIG2);
        conf1.setText("This is the first config object");
        conf2.setText("This is the second config object");
        
        ConfigurationMap writeMap = new ConfigurationMap();
        writeMap.setName(configMapName);
        writeMap.setConfiguration(conf1);
        writeMap.setConfiguration(conf2);
        
        writeMap.write( outFile );
        
        ConfigurationMap readMap = new ConfigurationMap(configMapName, outURL);
        FooConfig conf = (FooConfig)readMap.getConfiguration(CONFIG1);
    }
    
    public void testConfigLocate() {
    	String fooConfigKey = "fooConfig";
    	String configInstanceKey = "config1";
    	FooConfig fooConfig = 
    	   (FooConfig)ConfigurationLocator.getConfiguration(fooConfigKey, configInstanceKey);
    	assertTrue("FooConfig fetch did not get right config", 
    						configInstanceKey.equals(fooConfig.getKey()));    	
    	
    }
    
    public void testBadConfigFile() {
        // try reading in a bad config file
        String badConfigMapName = "badConfigMap.xml";
        URL tstResourceDir = TstTimeResourceLocator.getTstTimeResourceDir();
        URL badConfigURL = null;
        try {
            badConfigURL = URLUtil.createURL(tstResourceDir.toString(), badConfigMapName);
        } catch (Exception e) {
            fail("Couldn't create test URL");
        }
        
        String configMapName = "configMapTest";
        try {
            ConfigurationMap readMap = new ConfigurationMap(configMapName, badConfigURL);
            // fail("Didn't get a proper exception from a bad config file");
            // turns out very few things will force an actual exception
            // TODO investigate
        } catch (EnvironmentException e) {
            // a successful ignore - hooray
        }
    }
    
}
